@@ -6,10 +6,12 @@ from typing import Literal
 
 # Error codes returned by the SDK
 ErrorCode = Literal[
-    "unauthorized",  # Invalid or missing API key
+    "unauthorized",  # Authorization related error
+    "invalid_request",  # Request format error
     "server_error",  # Server-side error occurred
     "timeout",  # Operation timed out
     "invalid_file",  # File not found or invalid format
+    "file_too_large",  # File too large to upload.
     "upload_failed",  # Failed to upload the file
     "not_found",  # Requested resource not found
     "unknown_error",  # Unexpected error
